@@ -118,13 +118,12 @@ def dummy_code(
             
                 else:
                     f.write(f"\n    df['{d}'] = np.where(df['{d.split('_dummy_')[0]}'] == {d.split('_dummy_')[1]}, 1, 0)")
-                    f.write(f"\n    df['{d}'] = np.where(df['{d.split('_dummy_')[0]}'] == {d.split('_dummy_')[1]}, 1, 0)")
                 
             except ValueError:
                 f.write(f"\n    df['{d}'] = np.where(df['{d.split('_dummy_')[0]}'] == '{d.split('_dummy_')[1]}', 1, 0)")
         
         #model_pte_df['max_historical_user_count_change_dummy_1.0'] = np.where(model_pte_df['max_historical_user_count_change'] == 1, 1, 0)
-        f.write('\n\n    return')
+        f.write('\n\n    return df')
         f.close()
 
     return new_df
@@ -223,7 +222,7 @@ def dummy_top(
             new_df.drop(columns=[d], inplace=True)
             
     if output_file != None: 
-        f.write('\n\n    return')
+        f.write('\n\n    return df')
         f.close()
 
     return new_df
