@@ -3,6 +3,7 @@ import warnings
 import numpy as np
 import seaborn as sns
 from sklearn import metrics
+import shap
 
 def model_metrics(
     model,
@@ -37,9 +38,7 @@ def model_metrics(
         features.sort_values(by=["importance"], ascending=False, inplace=True)
         display(features)
 
-    if algo == "xgb":
-
-        import shap
+    elif algo == "xgb":
 
         # explain the model's predictions using SHAP
         explainer = shap.Explainer(model)
@@ -62,7 +61,7 @@ def model_metrics(
         features = result.sort_values(by=["importance"], ascending=False).head(top_features_n)
         # display(features)
 
-    if algo == "rf":
+    elif algo == "rf":
 
         importance = pd.DataFrame(model.feature_importances_)
 
@@ -75,9 +74,36 @@ def model_metrics(
 
         sns.set_theme(style="whitegrid")
         sns.set(rc={"figure.figsize": (11, 8)})
-        ax = sns.barplot(x="features", y="importance", data=features_top)
+        ax = sns.barplot(x="features", y="importance", data=features)
         ax.set_xticklabels(ax.get_xticklabels(), rotation=45, ha="right")
         ax.set(title="Top 20 features for account expansion")
+        
+        
+    else:
+        try:
+            masker = shap.maskers.Independent(data = x_test)
+            explainer = shap.Explainer(model, masker)
+            shap_values = explainer(x_train)
+
+            # mean absolute value of the SHAP values
+            print("Feature Importance")
+            shap.plots.bar(shap_values, max_display=20)
+
+            # visualize the first prediction's explanation with a force plot
+            shap.plots.beeswarm(shap_values, max_display=20)
+
+            # Assign shap values based on test dataset
+            shap_values = explainer.shap_values(x_test)
+
+            importance = pd.DataFrame(np.abs(shap_values).mean(0))
+            features = pd.DataFrame(x_test.columns)
+            result = pd.concat([features, importance], axis=1)
+            result.columns = ["features", "importance"]
+            features = result.sort_values(by=["importance"], ascending=False).head(top_features_n)
+            display(features)
+            
+        except:
+            warnings.warn('Feature Importance could not be computed.')
 
     # TRAIN DATA: Get Predicted and Actual
     score_train = model.predict_proba(x_train)
@@ -450,8 +476,12 @@ def model_metrics(
     display(score_test[["predicted", "actual", "decile"]].describe())
     display(x_test.describe())
         
-    print(f"\n\nFeature List: \n{x_test.columns.tolist()}\n")
-    top_features = features
+    try:
+        top_features = features
+    except:
+        top_features = x_test.columns.tolist()
+        
+    print(f"\n\nAll features in model: \n{x_test.columns.tolist()}\n")
             
     if classification == True:
         return metricx, lift, classification_metricx, top_features
