@@ -1,15 +1,19 @@
+import pandas as pd
+from scipy import stats
+import numpy as np
+
 def mad_outliers(
-    df,
-    dv=None,
-    min_levels=10,
+    df:pd.DataFrame,
+    dv:str=None,
+    min_levels:int=10,
     columns="all",
     threshold=4,
-    inplace=False,
-    verbose=True,
-    windsor_threshold=0.01,
+    inplace:bool=False,
+    verbose:bool=True,
+    windsor_threshold:float=0.01,
     output_file = None,
     output_method = 'a'
-):
+) -> pd.DataFrame:
     """
     Median Absoutely Deviation for outlier detection and correction. By default will windsor all numeric values in your dataframe that are more than 4 standard deviations above or below the median ('threshold').
 
@@ -41,10 +45,6 @@ def mad_outliers(
 
     """
 
-    from scipy import stats
-    import pandas as pd
-    import numpy as np
-
     print("\nOutliers\n")
     
     if output_file != None:
